pro ssw_findstuff_mark, index, data, reg, rinfo, rnumber, $
   lcolor=lcolor, bcolor=bcolor, fact=fact, label=label, debug=debug, $
   contour=contour, box=box, _extra=_extra, charsize=charsize, $
   initialize=initialize
;+
;   Name: region_mark
;
;   Purpose: mark region(s) on current device
;
;   Input Parameters:
;        index,data,reg,rinfo (output from ssw_limbstuff.pro)
;        rnumber - relative region to mark
;
;   Keyword Parameters:
;      fact     - maginification factor (relative to data)
;      label    - optional  label for  region  
;      countour - if set, mark region with contour 
;      box      - if set, mark with box
;      _extra   - keyword inheritapass to ocontour
;      bcolor   - if set, color for boxes
;      lcolor   - if set, color for labels  
;  
;   History:
;      18-Jun-1997 - S.L.Freeland - for ssw_limbstuff work
;      22-sep-2003 - S.L.Freeland - update to use plot_map et al
;
;-  

common ssw_findstuff_mark_blk, imap, rmap

initialize=keyword_set(initialize) or 1-data_chk(rmap,/struct)


contour=keyword_set(contour)
box=keyword_set(box) or keyword_set(bcolor)           ; bcolor implies /box
debug=keyword_set(debug)
if n_elements(fact) eq 0 then fact=1.
dxy=fact*4
sx=(size(data))(1)*fact
sy=(size(data))(2)*fact
ninfo=n_elements(rinfo)
if not keyword_set(bcolor) then bcolor=140         
if not keyword_set(lcolor) then lcolor=!p.color else $  ; lcolor implies label
    if not keyword_set(label) then label=1

if n_elements(label) eq 1 then label='!6'+strtrim(rinfo.rnum,2)
if n_params() eq  5 then which=rnumber else which=lindgen(ninfo)

if contour then $
   if fact eq 1 then tregion=reg else tregion=round(congrid(reg,sx,sy))

empty=make_array(sx,sy,/byte)               ; make an empty template

if not keyword_set(charsize) then charsize=1+fact*.5
					     
if initialize then begin 
   index2map,index,data,imap
   index2map,index,reg,rmap
   plot_map,imap,log=max(imap.data gt 256),_extra=_extra
endif

for i=0,n_elements(which)-1 do begin
   ss=which(i)
   rnum=rinfo(ss).rnum
   tmap=rmap
   tmap.data = tmap.data * (tmap.data eq rnum)
;   plot_map,tmap,levels=rnum,/over,_EXTRA=_EXTRA
   smap=get_sub_map(rmap,xrange=rinfo(i).extentx,yrange=rinfo(i).extenty,/pix)
   if contour then begin
      plot_map,smap,/over,levels=rnum,border=box
   endif
   if keyword_set(label) then begin
;     label outside box - avoid overlaps via quadrant dependent postioning
      xwid=data_chk(smap.data,/x)/2.
      ywid=data_chk(smap.data,/y)/2.
      x0=smap.xc - (smap.dx * xwid) & x1=smap.xc + (smap.dx * xwid)
      y0=smap.yc - (smap.dy * ywid) & y1=smap.yc + (smap.dy * ywid) 
      outx=([x0,x1])(X0 gt 0)
      outy=([y0,y1])(y1 gt 0)  
      align=([0,1])(x0 lt 0)
      xyouts,outx,outy,align=align,label(ss),/data,charsize=charsize, color=lcolor
if debug then stop,'post label
   endif
endfor
end
							       
